/*
 * e-soup-ssl-trust.h
 *
 * This library is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#if !defined (__LIBEDATASERVER_H_INSIDE__) && !defined (LIBEDATASERVER_COMPILATION)
#error "Only <libedataserver/libedateserver.h> should be included directly."
#endif

#ifndef E_SOUP_SSL_TRUST_H
#define E_SOUP_SSL_TRUST_H

#include <libedataserver/e-source.h>

#include <libsoup/soup.h>

G_BEGIN_DECLS

void		e_soup_ssl_trust_connect	(SoupMessage *soup_message,
						 ESource *source);

G_END_DECLS

#endif /* E_SOUP_SSL_TRUST_H */
