
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef E_CAL_ENUMTYPES_H
#define E_CAL_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "e-cal-enums.h" */
#define E_TYPE_CAL_CLIENT_SOURCE_TYPE	(e_cal_client_source_type_get_type())
GType e_cal_client_source_type_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_OBJ_MOD_TYPE	(e_cal_obj_mod_type_get_type())
GType e_cal_obj_mod_type_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_COMPONENT_VTYPE	(e_cal_component_vtype_get_type())
GType e_cal_component_vtype_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_COMPONENT_CLASSIFICATION	(e_cal_component_classification_get_type())
GType e_cal_component_classification_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_COMPONENT_PERIOD_KIND	(e_cal_component_period_kind_get_type())
GType e_cal_component_period_kind_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_COMPONENT_RANGE_KIND	(e_cal_component_range_kind_get_type())
GType e_cal_component_range_kind_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_COMPONENT_TRANSPARENCY	(e_cal_component_transparency_get_type())
GType e_cal_component_transparency_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_COMPONENT_ALARM_ACTION	(e_cal_component_alarm_action_get_type())
GType e_cal_component_alarm_action_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_COMPONENT_ALARM_TRIGGER_KIND	(e_cal_component_alarm_trigger_kind_get_type())
GType e_cal_component_alarm_trigger_kind_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_RECUR_DESCRIBE_RECURRENCE_FLAGS	(e_cal_recur_describe_recurrence_flags_get_type())
GType e_cal_recur_describe_recurrence_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_OPERATION_FLAGS	(e_cal_operation_flags_get_type())
GType e_cal_operation_flags_get_type	(void) G_GNUC_CONST;
#define E_TYPE_CAL_INTERVAL_UNITS	(e_cal_interval_units_get_type())
GType e_cal_interval_units_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_CAL_ENUMTYPES_H */

/* Generated data ends here */

