/*
 * libebackend.h
 *
 * This library is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef LIBEBACKEND_H
#define LIBEBACKEND_H

#define __LIBEBACKEND_H_INSIDE__

#include <libedataserver/libedataserver.h>

#include <libebackend/e-backend-enums.h>
#include <libebackend/e-backend-enumtypes.h>
#include <libebackend/e-backend-factory.h>
#include <libebackend/e-backend.h>
#include <libebackend/e-cache.h>
#include <libebackend/e-cache-keys.h>
#include <libebackend/e-cache-reaper.h>
#include <libebackend/e-collection-backend-factory.h>
#include <libebackend/e-collection-backend.h>
#include <libebackend/e-data-factory.h>
#include <libebackend/e-dbus-server.h>
#include <libebackend/e-file-cache.h>
#include <libebackend/e-oauth2-support.h>
#include <libebackend/e-offline-listener.h>
#include <libebackend/e-server-side-source.h>
#include <libebackend/e-source-registry-server.h>
#include <libebackend/e-sqlite3-vfs.h>
#include <libebackend/e-subprocess-factory.h>
#include <libebackend/e-user-prompter.h>
#include <libebackend/e-user-prompter-server.h>
#include <libebackend/e-user-prompter-server-extension.h>
#include <libebackend/e-webdav-collection-backend.h>

#include <libebackend/e-backend-autocleanups.h>

#undef __LIBEBACKEND_H_INSIDE__

#endif /* LIBEBACKEND_H */

